@@ -41,7 +41,7 @@ function assign(ta) {
 	if (!ta || !ta.nodeName || ta.nodeName !== 'TEXTAREA' || map.has(ta)) return;
 
 	let heightOffset = null;
-	let clientWidth = ta.clientWidth;
+	let clientWidth = null;
 	let cachedHeight = null;
 
 	function init() {
@@ -100,21 +100,16 @@ function assign(ta) {
 	}
 
 	function resize() {
-		const originalHeight = ta.style.height;
-		const overflows = getParentOverflows(ta);
-		const docTop = document.documentElement && document.documentElement.scrollTop; // Needed for Mobile IE (ticket #240)
-
-		ta.style.height = 'auto';
-
-		let endHeight = ta.scrollHeight+heightOffset;
-
 		if (ta.scrollHeight === 0) {
 			// If the scrollHeight is 0, then the element probably has display:none or is detached from the DOM.
-			ta.style.height = originalHeight;
 			return;
 		}
 
-		ta.style.height = endHeight+'px';
+		const overflows = getParentOverflows(ta);
+		const docTop = document.documentElement && document.documentElement.scrollTop; // Needed for Mobile IE (ticket #240)
+
+		ta.style.height = '';
+		ta.style.height = (ta.scrollHeight+heightOffset)+'px';
 
 		// used to check if an update is actually necessary on window.resize
 		clientWidth = ta.clientWidth;
@@ -140,7 +135,7 @@ function assign(ta) {
 
 		// The actual height not matching the style height (set via the resize method) indicates that 
 		// the max-height has been exceeded, in which case the overflow should be allowed.
-		if (actualHeight !== styleHeight) {
+		if (actualHeight < styleHeight) {
 			if (computed.overflowY === 'hidden') {
 				changeOverflow('scroll');
 				resize();
@@ -173,7 +168,7 @@ function assign(ta) {
 		}
 	};
 
-	const destroy = style => {
+	const destroy = (style => {
 		window.removeEventListener('resize', pageResize, false);
 		ta.removeEventListener('input', update, false);
 		ta.removeEventListener('keyup', update, false);
@@ -185,7 +180,7 @@ function assign(ta) {
 		});
 
 		map.delete(ta);
-	}.bind(ta, {
+	}).bind(ta, {
 		height: ta.style.height,
 		resize: ta.style.resize,
 		overflowY: ta.style.overflowY,
